@@ -42,7 +42,7 @@ DoubleSpinBox::DoubleSpinBox( double lower, double upper, double minAbs, double
 	
 	editor()->setAlignment( TQt::AlignRight );
 	
-	connect( this, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(checkIfChanged()) );
+	connect( this, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(checkIfChanged()) );
 	TQSpinBox::setMinValue( -(1<<30) );
 	TQSpinBox::setMaxValue( +(1<<30) );	
 	setValue( value );
@@ -94,7 +94,7 @@ void DoubleSpinBox::updateSuffix( double value )
 	if ( m_queuedSuffix.stripWhiteSpace().isEmpty() )
 		m_queuedSuffix = "";
 	
-	TQTimer::singleShot( 0, this, TQT_SLOT(setQueuedSuffix()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(setQueuedSuffix()) );
 }
 
 
