@@ -56,10 +56,10 @@ ItemSelector::ItemSelector( TQWidget *parent, const char *name )
     setRootIsDecorated(true);
     setDragEnabled(true);
 	
-// 	connect( this, TQT_SIGNAL(executed(TQListViewItem*) ), this, TQT_SLOT(slotItemExecuted(TQListViewItem*)) );
-	connect( this, TQT_SIGNAL(clicked(TQListViewItem*)), this, TQT_SLOT(slotItemClicked(TQListViewItem*)) );
-	connect( this, TQT_SIGNAL(doubleClicked(TQListViewItem*)), this, TQT_SLOT(slotItemDoubleClicked(TQListViewItem*)) );
-	connect( this, TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int )), this, TQT_SLOT(slotContextMenuRequested(TQListViewItem*, const TQPoint&, int )) );
+// 	connect( this, TQ_SIGNAL(executed(TQListViewItem*) ), this, TQ_SLOT(slotItemExecuted(TQListViewItem*)) );
+	connect( this, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(slotItemClicked(TQListViewItem*)) );
+	connect( this, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(slotItemDoubleClicked(TQListViewItem*)) );
+	connect( this, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int )), this, TQ_SLOT(slotContextMenuRequested(TQListViewItem*, const TQPoint&, int )) );
 }
 
 ItemSelector::~ItemSelector()
@@ -163,7 +163,7 @@ void ItemSelector::slotContextMenuRequested( TQListViewItem* item, const TQPoint
 	}
 	
 	TQPopupMenu *menu = new TQPopupMenu(this);
-	menu->insertItem( i18n("Remove %1").arg(item->text(0)), this, TQT_SLOT(slotRemoveSelectedItem()), TQt::Key_Delete );
+	menu->insertItem( i18n("Remove %1").arg(item->text(0)), this, TQ_SLOT(slotRemoveSelectedItem()), TQt::Key_Delete );
 	menu->popup(pos);
 }
 
